==> jonas-JONAS_4_10_3.tar.bz2: jonas-JONAS_4_10_3/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/EditJoramServerAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import javax.management.InstanceNotFoundException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;

/**
 * @author Adriana Danes
 */

public class EditJoramServerAction extends EditJoramBaseAction {

//	--------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping pMapping, ActionForm pForm
            , HttpServletRequest pRequest, HttpServletResponse pResponse)
    throws IOException, ServletException {

        // Current JOnAS server
        String serverName =  m_WhereAreYou.getCurrentJonasServerName();

        // Serve id currently in management
        String id = pRequest.getParameter("id");
        if (id == null) {
            id = (String) m_Session.getAttribute("currentId");
        } else {
            m_Session.setAttribute("currentId", id);
        }
        String localId = (String) m_Session.getAttribute("localId");
        boolean collocatedServer = ((Boolean) m_Session.getAttribute("collocatedServer")).booleanValue();
        boolean isLocalServer;
        if (localId.equals(id)) {
            isLocalServer = true;
        } else {
            isLocalServer = false;
        }

        m_Session.setAttribute("isLocalServer", new Boolean(isLocalServer));
        // Get reference on EJB container service in order to determine dependencies
        // between the deployed EJBs and JMS destinations
        initRefs(serverName);

        try {
            Set adapterOns = JonasManagementRepr.queryNames(JoramObjectName.joramAdapter(), serverName);
            if (adapterOns.isEmpty()) {
                throw new InstanceNotFoundException();
            }
            ObjectName joramAdapterON = (ObjectName) adapterOns.iterator().next();
            boolean isAdapterLoaded = JonasManagementRepr.isRegistered(joramAdapterON, serverName);
            ObjectName joramAdminON = JoramObjectName.joramAdmin();

            ArrayList destinationsArray = new ArrayList();
            ArrayList topicsArray = new ArrayList();
            Iterator destinationsList = ((List) JonasManagementRepr.getAttribute(joramAdminON, "Destinations", serverName)).iterator();
            for (; destinationsList.hasNext();) {
                String destinationString = (String) destinationsList.next();
                ItemDestination destinationItem = getDestinationItem(destinationString, serverName);
                String destName = destinationItem.getName();
                if (destinationItem.getServerId().equals(id)
                        /*&& destinationItem.getOn() != null*/) {
                    // Put queues to destinationsArray and topics to TopicsArray
                    if (destinationItem.getType().equals("queue") || destinationItem.getType().equals("queue.dmq")) {
                        destinationsArray.add(destinationItem);
                    } else if (destinationItem.getType().equals("topic")) {
                        topicsArray.add(destinationItem);
                    }
                    //printDestination(destinationItem, serverName);
                }
            }
            // sort queues
            Collections.sort(destinationsArray, new ItemDestinationByName());
            // sort topics
            Collections.sort(topicsArray, new ItemDestinationByName());
            // append topics to queues
            destinationsArray.addAll(topicsArray);

            ArrayList usersArray = new ArrayList();
            Iterator usersList;
            if (isLocalServer) {
                usersList = ((List) JonasManagementRepr.getAttribute(joramAdapterON, "LocalUsers", serverName)).iterator();
            } else {
                usersList = ((List) JonasManagementRepr.getAttribute(joramAdminON, "Users", serverName)).iterator();
            }
            for (; usersList.hasNext();) {
                String userString = (String) usersList.next();
                ItemUser userItem = getUserItem(userString, serverName);
                if (userItem.getName() != null
                        && userItem.getServerId().equals(id)) {
                    usersArray.add(userItem);
                    //printUser(userItem);
                }
            }

            m_Session.setAttribute("destinations", destinationsArray);
            m_Session.setAttribute("users", usersArray);
        } catch (Throwable t) {
            return (treatError(t, pMapping, pRequest));
        }

        // Force the node selected in tree
        String nodeName = null;
        if (isLocalServer) {
            if (collocatedServer) {
                nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform" + WhereAreYou.NODE_SEPARATOR
                + "joramlocalserver";
            } else {
                nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform" + WhereAreYou.NODE_SEPARATOR
                + "joramcurrentserver";

            }
            m_WhereAreYou.selectNameNode(nodeName, true);
            // Forward to the jsp.
            return (pMapping.findForward("JoramDestinations"));
        } else {
            nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
            + "joramplatform" + WhereAreYou.NODE_SEPARATOR
            + "joramremoteserver" + id;
            m_WhereAreYou.selectNameNode(nodeName, true);
            return (pMapping.findForward("JoramRemoteDestinations"));
        }

    }

}

==> jonas-JONAS_4_10_4.tar.bz2: jonas-JONAS_4_10_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/EditJoramServerAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import javax.management.InstanceNotFoundException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;

/**
 * @author Adriana Danes
 */

public class EditJoramServerAction extends EditJoramBaseAction {

//	--------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping pMapping, ActionForm pForm
            , HttpServletRequest pRequest, HttpServletResponse pResponse)
    throws IOException, ServletException {

        // Current JOnAS server
        String serverName =  m_WhereAreYou.getCurrentJonasServerName();

        // Serve id currently in management
        String id = pRequest.getParameter("id");
        if (id == null) {
            id = (String) m_Session.getAttribute("currentId");
        } else {
            m_Session.setAttribute("currentId", id);
        }
        String localId = (String) m_Session.getAttribute("localId");
        boolean collocatedServer = ((Boolean) m_Session.getAttribute("collocatedServer")).booleanValue();
        boolean isLocalServer;
        if (localId.equals(id)) {
            isLocalServer = true;
        } else {
            isLocalServer = false;
        }

        m_Session.setAttribute("isLocalServer", new Boolean(isLocalServer));
        // Get reference on EJB container service in order to determine dependencies
        // between the deployed EJBs and JMS destinations
        initRefs(serverName);

        try {
            ObjectName joramAdapterON = JoramObjectName.joramAdapter();
            boolean isAdapterLoaded = JonasManagementRepr.isRegistered(joramAdapterON, serverName);

            ArrayList destinationsArray = new ArrayList();
            ArrayList topicsArray = new ArrayList();
            String[] destinationsList = (String[]) JonasManagementRepr.getAttribute(joramAdapterON, "Destinations", serverName);
            for (int i = 0; i < destinationsList.length; i++) {
                String destinationString = destinationsList[i];
                ItemDestination destinationItem = getDestinationItem(destinationString, serverName);
                String destName = destinationItem.getName();
                // TODO
                // see if it is necessary or not to check the Id 
                // ??
                //if (destinationItem.getServerId().equals(id)/*&& destinationItem.getOn() != null*/) {
                    // Put queues to destinationsArray and topics to TopicsArray
                    if (destinationItem.getType().equals("Queue")) {
                        destinationsArray.add(destinationItem);
                    } else if (destinationItem.getType().equals("Topic")) {
                        topicsArray.add(destinationItem);
                    }
                    //printDestination(destinationItem, serverName);
                //}
            }
            
            // sort queues
            Collections.sort(destinationsArray, new ItemDestinationByName());
            // sort topics
            Collections.sort(topicsArray, new ItemDestinationByName());
            // append topics to queues
            destinationsArray.addAll(topicsArray);

            ArrayList usersArray = new ArrayList();
            String[] usersList = (String[]) JonasManagementRepr.getAttribute(joramAdapterON, "Users", serverName);
            for (int i = 0; i < usersList.length; i++) {
                String userString = usersList[i];
                ItemUser userItem = getUserItem(userString, serverName);
                if (userItem.getName() != null)
                        /* TODO check with Joram team if necessary
                         * && userItem.getServerId().equals(id)) */
                		{
                    usersArray.add(userItem);
                    //printUser(userItem);
                }
            }

            m_Session.setAttribute("destinations", destinationsArray);
            m_Session.setAttribute("users", usersArray);
        } catch (Throwable t) {
            return (treatError(t, pMapping, pRequest));
        }

        // Force the node selected in tree
        String nodeName = null;
        if (isLocalServer) {
            if (collocatedServer) {
                nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform" + WhereAreYou.NODE_SEPARATOR
                + "joramlocalserver";
            } else {
                nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform" + WhereAreYou.NODE_SEPARATOR
                + "joramcurrentserver";

            }
            m_WhereAreYou.selectNameNode(nodeName, true);
            // Forward to the jsp.
            return (pMapping.findForward("JoramDestinations"));
        } else {
            nodeName = getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
            + "joramplatform" + WhereAreYou.NODE_SEPARATOR
            + "joramremoteserver" + id;
            m_WhereAreYou.selectNameNode(nodeName, true);
            return (pMapping.findForward("JoramRemoteDestinations"));
        }

    }

}
